==> chaosmesh-model-6.3.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodNetworkChaosListFluent<A extends PodNetworkChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,PodNetworkChaos item);
  public A setToItems(Integer index,PodNetworkChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.PodNetworkChaos... items);
  public A addAllToItems(Collection<PodNetworkChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.PodNetworkChaos... items);
  public A removeAllFromItems(Collection<PodNetworkChaos> items);
  public A removeMatchingFromItems(Predicate<PodNetworkChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodNetworkChaos> getItems();
  public List<PodNetworkChaos> buildItems();
  public PodNetworkChaos buildItem(Integer index);
  public PodNetworkChaos buildFirstItem();
  public PodNetworkChaos buildLastItem();
  public PodNetworkChaos buildMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
  public A withItems(List<PodNetworkChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.PodNetworkChaos... items);
  public Boolean hasItems();
  public PodNetworkChaosListFluent.ItemsNested<A> addNewItem();
  public PodNetworkChaosListFluent.ItemsNested<A> addNewItemLike(PodNetworkChaos item);
  public PodNetworkChaosListFluent.ItemsNested<A> setNewItemLike(Integer index,PodNetworkChaos item);
  public PodNetworkChaosListFluent.ItemsNested<A> editItem(Integer index);
  public PodNetworkChaosListFluent.ItemsNested<A> editFirstItem();
  public PodNetworkChaosListFluent.ItemsNested<A> editLastItem();
  public PodNetworkChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PodNetworkChaosFluent<PodNetworkChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodNetworkChaosListFluent<A extends PodNetworkChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,PodNetworkChaos item);
  public A setToItems(int index,PodNetworkChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.PodNetworkChaos... items);
  public A addAllToItems(Collection<PodNetworkChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.PodNetworkChaos... items);
  public A removeAllFromItems(Collection<PodNetworkChaos> items);
  public A removeMatchingFromItems(Predicate<PodNetworkChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodNetworkChaos> getItems();
  public List<PodNetworkChaos> buildItems();
  public PodNetworkChaos buildItem(int index);
  public PodNetworkChaos buildFirstItem();
  public PodNetworkChaos buildLastItem();
  public PodNetworkChaos buildMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
  public A withItems(List<PodNetworkChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.PodNetworkChaos... items);
  public Boolean hasItems();
  public PodNetworkChaosListFluent.ItemsNested<A> addNewItem();
  public PodNetworkChaosListFluent.ItemsNested<A> addNewItemLike(PodNetworkChaos item);
  public PodNetworkChaosListFluent.ItemsNested<A> setNewItemLike(int index,PodNetworkChaos item);
  public PodNetworkChaosListFluent.ItemsNested<A> editItem(int index);
  public PodNetworkChaosListFluent.ItemsNested<A> editFirstItem();
  public PodNetworkChaosListFluent.ItemsNested<A> editLastItem();
  public PodNetworkChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,PodNetworkChaosFluent<PodNetworkChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
